@@ -50,7 +50,6 @@ from . import adapter_ficbooknet
 from . import adapter_midnightwhispers
 from . import adapter_ksarchivecom
 from . import adapter_archiveskyehawkecom
-from . import adapter_squidgeorgpeja
 from . import adapter_libraryofmoriacom
 from . import adapter_wraithbaitcom
 from . import adapter_ashwindersycophanthexcom
@@ -72,7 +71,6 @@ from . import adapter_pretendercentrecom
 from . import adapter_darksolaceorg
 from . import adapter_finestoriescom
 from . import adapter_hpfanficarchivecom
-from . import adapter_nhamagicalworldsus
 from . import adapter_hlfictionnet
 from . import adapter_dracoandginnycom
 from . import adapter_scarvesandcoffeenet
@@ -82,7 +80,6 @@ from . import adapter_thehookupzonenet
 from . import adapter_bloodtiesfancom
 from . import adapter_qafficcom
 from . import adapter_efpfanficnet
-from . import adapter_faeriearchivecom
 from . import adapter_imagineeficcom
 from . import adapter_potterheadsanonymouscom
 from . import adapter_storiesonlinenet
@@ -97,9 +94,7 @@ from . import adapter_themaplebookshelf
 from . import adapter_sheppardweircom
 from . import adapter_samandjacknet
 from . import adapter_csiforensicscom
-from . import adapter_fanfictionjunkiesde
 from . import adapter_tgstorytimecom
-from . import adapter_itcouldhappennet
 from . import adapter_forumsspacebattlescom
 from . import adapter_forumssufficientvelocitycom
 from . import adapter_forumquestionablequestingcom
@@ -126,7 +121,6 @@ from . import adapter_sugarquillnet
 from . import adapter_starslibrarynet
 from . import adapter_fanficauthorsnet
 from . import adapter_fireflyfansnet
-from . import adapter_sebklainenet
 from . import adapter_shriftweborgbfa
 from . import adapter_trekfanfictionnet
 from . import adapter_wuxiaworldcom
@@ -153,7 +147,6 @@ from . import adapter_novelonlinefullcom
 from . import adapter_wwwnovelallcom
 from . import adapter_wuxiaworldco
 from . import adapter_novelupdatescc
-from . import adapter_harrypotterfanfictioncom
 from . import adapter_hentaifoundrycom
 from . import adapter_mugglenetfanfictioncom
 from . import adapter_swiorgru
@@ -169,6 +162,7 @@ from . import adapter_thesietchcom
 from . import adapter_fastnovelnet
 from . import adapter_squidgeworldorg
 from . import adapter_novelfull
+from . import adapter_worldofxde
 
 ## This bit of complexity allows adapters to be added by just adding
 ## importing.  It eliminates the long if/else clauses we used to need
