@@ -134,6 +134,11 @@ class BaseXenForo2ForumAdapter(BaseXenForoForumAdapter):
                         if img.has_attr('srcset'):
                             src = img['srcset']
                         self.setCoverImage(useurl,src)
+        stats = topsoup.find('span',class_='block-formSectionHeader-aligner')
+        if stats:
+            m = re.search(r' (?P<words>[^ ]+) words\)',stripHTML(stats))
+            if m:
+                self.story.setMetadata('estimatedWords',m.group('words'))
         return
 
     def get_forumtags(self,topsoup):
@@ -164,7 +169,7 @@ class BaseXenForo2ForumAdapter(BaseXenForoForumAdapter):
             # logger.debug(authorcard)
             covera = authorcard.find('span',{'class':'avatarWrapper'}).find('a')
             if covera:
-                self.setCoverImage(self.url,self.getURLDomain()+covera['href'])
+                self.setCoverImage(self.url,covera['href'])
 
     def cache_posts(self,topsoup):
         for post in topsoup.find_all('article',{'class':'message--post'}):
@@ -203,7 +208,7 @@ class BaseXenForo2ForumAdapter(BaseXenForoForumAdapter):
         return body
 
     def get_post_created_date(self,souptag):
-        return self.make_date(souptag.find('div', {'class':'message-date'}))
+        return self.make_date(souptag.find('div', {'class':'message-attribution-main'}))
 
     def get_post_updated_date(self,souptag):
         return self.make_date(souptag.find('div',{'class':'message-lastEdit'}))
