@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2015 Fanficdownloader team, 2019 FanFicFare team
+# Copyright 2015 Fanficdownloader team, 2021 FanFicFare team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -42,6 +42,7 @@ except ImportError:
 from . import exceptions
 from . import fetcher
 from . import nsapa_proxy
+from . import flaresolverr_proxy
 
 ## has to be up here for brotli-dict to load correctly.
 from .browsercache import BrowserCache
@@ -197,12 +198,13 @@ def get_valid_set_options():
                'use_cloudscraper':(None,None,boollist),
                'use_basic_cache':(None,None,boollist),
                'use_nsapa_proxy':(None,None,boollist),
+               'use_flaresolverr_proxy':(None,None,boollist),
 
                ## currently, browser_cache_path is assumed to be
                ## shared and only ffnet uses it so far
                'browser_cache_path':(['defaults'],None,None),
-               'use_browser_cache':(['fanfiction.net'],None,boollist),
-               'use_browser_cache_only':(['fanfiction.net'],None,boollist),
+               'use_browser_cache':(['fanfiction.net','fictionpress.com','ficbook.net'],None,boollist),
+               'use_browser_cache_only':(['fanfiction.net','fictionpress.com','ficbook.net'],None,boollist),
 
                'continue_on_chapter_error':(None,None,boollist),
                'conditionals_use_lists':(None,None,boollist),
@@ -281,6 +283,8 @@ def get_valid_set_options():
                'use_threadmark_wordcounts':(base_xenforo_list,None,boollist),
                'always_include_first_post_chapters':(base_xenforo_list,None,boollist),
                'order_threadmarks_by_date':(base_xenforo_list,None,boollist),
+               'order_threadmarks_by_date_categories':(base_xenforo_list,None,boollist),
+               'reveal_invisible_text':(base_xenforo_list,None,boollist),
                'use_threadmarks_description':(base_xenforo2_list,None,boollist),
                'use_threadmarks_status':(base_xenforo2_list,None,boollist),
                'use_threadmarks_cover':(base_xenforo2_list,None,boollist),
@@ -480,6 +484,8 @@ def get_valid_keywords():
                  'tweak_fg_sleep',
                  'universe_as_series',
                  'use_ssl_unverified_context',
+                 'http_proxy',
+                 'https_proxy',
                  'use_cloudscraper',
                  'use_basic_cache',
                  'use_browser_cache',
@@ -487,6 +493,9 @@ def get_valid_keywords():
                  'use_nsapa_proxy',
                  'nsapa_proxy_address',
                  'nsapa_proxy_port',
+                 'use_flaresolverr_proxy',
+                 'flaresolverr_proxy_address',
+                 'flaresolverr_proxy_port',
                  'browser_cache_path',
                  'browser_cache_age_limit',
                  'user_agent',
@@ -518,6 +527,8 @@ def get_valid_keywords():
                  'use_threadmark_wordcounts',
                  'always_include_first_post_chapters',
                  'order_threadmarks_by_date',
+                 'order_threadmarks_by_date_categories',
+                 'reveal_invisible_text',
                  'use_threadmarks_description',
                  'use_threadmarks_status',
                  'use_threadmarks_cover',
@@ -983,7 +994,11 @@ class Configuration(ConfigParser):
             cookiejar = self.get_fetcher().get_cookiejar()
             # save and re-apply cookiejar when make_new.
         if not self.fetcher or make_new:
-            if self.getConfig('use_nsapa_proxy',False):
+
+            if self.getConfig('use_flaresolverr_proxy',False):
+                logger.debug("use_flaresolverr_proxy:%s"%self.getConfig('use_flaresolverr_proxy'))
+                fetchcls = flaresolverr_proxy.FlareSolverr_ProxyFetcher
+            elif self.getConfig('use_nsapa_proxy',False):
                 logger.debug("use_nsapa_proxy:%s"%self.getConfig('use_nsapa_proxy'))
                 fetchcls = nsapa_proxy.NSAPA_ProxyFetcher
             elif self.getConfig('use_cloudscraper',False):
