@@ -291,10 +291,11 @@ class BrowserCacheDecorator(FetcherDecorator):
             usecache=usecache)
 
 class FetcherResponse(object):
-    def __init__(self,content,redirecturl=None,fromcache=False):
+    def __init__(self,content,redirecturl=None,fromcache=False,json=None):
         self.content = content
         self.redirecturl = redirecturl
         self.fromcache = fromcache
+        self.json = json
 
 class BasicCookieJar(LWPCookieJar,object):
     def __init__(self,*args,**kargs):
@@ -407,11 +408,11 @@ class RequestsFetcher(Fetcher):
 
     def make_retries(self):
         return Retry(total=4,
-                            other=0, # rather fail SSL errors/etc quick
-                            backoff_factor=2,# factor 2=4,8,16sec
-                            allowed_methods={'GET','POST'},
-                            status_forcelist={413, 429, 500, 502, 503, 504},
-                            raise_on_status=False) # to match w/o retries behavior
+                     other=0, # rather fail SSL errors/etc quick
+                     backoff_factor=2,# factor 2=4,8,16sec
+                     allowed_methods={'GET','POST'},
+                     status_forcelist={413, 429, 500, 502, 503, 504},
+                     raise_on_status=False) # to match w/o retries behavior
 
     def make_sesssion(self):
         return requests.Session()
@@ -420,6 +421,26 @@ class RequestsFetcher(Fetcher):
         session.mount('https://', HTTPAdapter(max_retries=self.retries))
         session.mount('http://', HTTPAdapter(max_retries=self.retries))
         session.mount('file://', FileAdapter())
+        # logger.debug("Session Proxies Before:%s"%session.proxies)
+        ## try to get OS proxy settings via Calibre
+        try:
+            # logger.debug("Attempting to collect proxy settings through Calibre")
+            from calibre import get_proxies
+            try:
+                proxies = get_proxies()
+                if proxies:
+                    logger.debug("Calibre Proxies:%s"%proxies)
+                session.proxies.update(proxies)
+            except Exception as e:
+                logger.error("Failed during proxy collect/set %s"%e)
+        except:
+            pass
+        if self.getConfig('http_proxy'):
+            session.proxies['http'] = self.getConfig('http_proxy')
+        if self.getConfig('https_proxy'):
+            session.proxies['https'] = self.getConfig('https_proxy')
+        if session.proxies:
+            logger.debug("Session Proxies After INI:%s"%session.proxies)
 
     def get_requests_session(self):
         if not self.requests_session:
@@ -433,7 +454,7 @@ class RequestsFetcher(Fetcher):
     def use_verify(self):
         return not self.getConfig('use_ssl_unverified_context',False)
 
-    def request(self,method,url,headers=None,parameters=None):
+    def request(self,method,url,headers=None,parameters=None,json=None):
         '''Returns a FetcherResponse regardless of mechanism'''
         if method not in ('GET','POST'):
             raise NotImplementedError()
@@ -443,14 +464,25 @@ class RequestsFetcher(Fetcher):
             resp = self.get_requests_session().request(method, url,
                                                        headers=headers,
                                                        data=parameters,
+                                                       json=json,
                                                        verify=self.use_verify())
             logger.debug("response code:%s"%resp.status_code)
             resp.raise_for_status() # raises RequestsHTTPError if error code.
             # consider 'cached' if from file.
             fromcache = resp.url.startswith('file:')
+            ## currently only saving response json if there input was json.
+            ## for flaresolverr_proxy
+            resp_json = None
+            if json:
+                try:
+                    resp_json = resp.json()
+                except:
+                    pass
+            # logger.debug(resp_json)
             return FetcherResponse(resp.content,
                                    resp.url,
-                                   fromcache)
+                                   fromcache,
+                                   resp_json)
         except RequestsHTTPError as e:
             ## not RequestsHTTPError(requests.exceptions.HTTPError) or
             ## .six.moves.urllib.error import HTTPError because we
@@ -513,7 +545,7 @@ class CloudScraperFetcher(RequestsFetcher):
             ## cloudscraper exception messages can appear to
             ## come from FFF and cause confusion.
             msg = unicode(cfe).replace(' in the opensource (free) version','...')
-            raise exceptions.FailedToDownload('cloudscraper reports: "%s"'%msg)
+            raise exceptions.FailedToDownload('cloudscraper reports: (%s) \nSee https://github.com/JimmXinu/FanFicFare/wiki/BrowserCacheFeature for a possible workaround.'%msg)
 
 # .? for AO3's ']' in param names.
 safe_url_re = re.compile(r'(?P<attr>(pass(word)?|name|login).?=)[^&]*(?P<amp>&|$)',flags=re.MULTILINE)
